compute.rmse: Root Mean Square Error (RMSE)

View source: R/1_4RMSE.R

compute.rmseR Documentation

Root Mean Square Error (RMSE)

Description

Estimates the Root Mean Square Error of two univariate signals Y (imputed values) and X (true values).

Usage

compute.rmse(Y, X)

Arguments

Y

vector of imputed values

X

vector of true values

Details

This function returns the value of RMSE of two vectors corresponding to univariate signals. A lower RMSE (RMSE \in [0, \inf]) value indicates a better performance method for the imputation task. Both vectors Y and X must be of equal length, on the contrary an error will be displayed. In both input vectors, eventual NA will be excluded with a warning displayed.

Examples

data(dataDTWBI)
X <- dataDTWBI[, 1] ; Y <- dataDTWBI[, 2]
compute.rmse(Y,X)

DTWBI documentation built on Sept. 9, 2026, 9:07 a.m.

Related to compute.rmse in DTWBI...