dist_afbdtw: Adaptive Feature Based Dynamic Time Warping algorithm

View source: R/2_2AFBDTW.R

dist_afbdtwR Documentation

Adaptive Feature Based Dynamic Time Warping algorithm

Description

This function estimates a distance matrix which is used as an input in dtw() function (package dtw) to align two univariate signals following Adaptative Feature Based Dynamic Time Warping algorithm (AFBDTW).

Usage

dist_afbdtw(q, r, w1 = 0.5)

Arguments

q

query vector

r

reference vector

w1

weight of local feature VS global feature. By default, w1 = 0.5, and by definition, w2 = 1 - w1.

Value

A list containing the following elements:

query

The query vector.

response

The response vector.

query_local

Local features of the query.

response_local

Local features of the response vector.

query_global

Global features of the query.

response_global

Global features of the response vector.

dist_local

Distance matrix of the local features.

dist_global

Distance matrix of the global features.

distAFBDTW

AFBDTW distance matrix.

Examples

data(dataDTWBI)
X <- dataDTWBI[, 1] ; Y <- dataDTWBI[, 2]
AFBDTW_Dist <- dist_afbdtw(X, Y)

DTWBI documentation built on Sept. 9, 2026, 9:07 a.m.

Related to dist_afbdtw in DTWBI...