dot-globalfeatures: Estimating global features of a univariate signal

.globalfeaturesR Documentation

Estimating global features of a univariate signal

Description

Computes global features of a univariate signal, used as input for threshold and window definition in DTWBI algorithm.

Usage

.globalfeatures(X)

Arguments

X

signal

Value

A matrix with one row, each column giving the value of corresponding estimated feature:

minx

Minimum value of the input vector.

maxx

Maximum value of the input vector.

avg

Average value of the input vector.

medianx

Median of the input vector.

std

Standard deviation of the input vector.

momx

Skewness of the input vector.

nop

Number of peaks in the input vector.

len

Length of the input vector.

entro

Entropy measure of the input vector.

Examples

data(dataDTWBI)
X <- dataDTWBI[, 1]
gf <- .globalfeatures(X)

DTWBI documentation built on Sept. 9, 2026, 9:07 a.m.