gapCreation: Gap creation

View source: R/3_1Create_large_gaps.R

gapCreationR Documentation

Gap creation

Description

This function creates a large continuous gap within a univariate signal. Gap size is defined as a percentage of input vector length. By default, the created gap starts at a random location.

Usage

gapCreation(X, rate, begin = NULL)

Arguments

X

input vector

rate

size of desired gap, as a percentage of input vector size

begin

location of the beginning of the gap (random by default)

Value

A list containing the following elements:

output_vector

Output vector containing the created gap.

input_vector

Original vector used as input.

begin_gap

Index of the beginning of the gap.

rate

Size of the created gap as a percentage of the input vector length.

gap_size

Length of the created gap.

Examples

data(dataDTWBI)
X <- dataDTWBI[, 1]
rate <- 0.1
output <- gapCreation(X, rate)
plot(output$input_vector, type = "l", col = "red", lwd = 2)
lines(output$output_vector, lty = "dashed", lwd = 2)

DTWBI documentation built on Sept. 9, 2026, 9:07 a.m.

Related to gapCreation in DTWBI...