| local.derivative.ddtw | R Documentation |
This function estimates the local derivative of a vector. It can be used as an input in dtw() function (package dtw) to align two univariate signals.
local.derivative.ddtw(X)
X |
input vector from which local derivative has to be calculated |
data(dataDTWBI)
X <- dataDTWBI[, 1]
local.derivative.ddtw(X)
# Plot
plot(X, type = "b", ylim = c(-1, 1))
lines(local.derivative.ddtw(X), col = "red")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.