| compute.rmse | R Documentation |
Estimates the Root Mean Square Error of two univariate signals Y (imputed values) and X (true values).
compute.rmse(Y, X)
Y |
vector of imputed values |
X |
vector of true values |
This function returns the value of RMSE of two vectors corresponding to univariate signals.
A lower RMSE (RMSE \in [0, \inf]) value indicates a better performance method for the imputation task.
Both vectors Y and X must be of equal length, on the contrary an error will be displayed.
In both input vectors, eventual NA will be excluded with a warning displayed.
data(dataDTWBI)
X <- dataDTWBI[, 1] ; Y <- dataDTWBI[, 2]
compute.rmse(Y,X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.