View source: R/1_1Similarity.R
| compute.sim | R Documentation |
Estimates the similarity of two univariate signals Y (imputed values) and X (true values).
compute.sim(Y, X)
Y |
vector of imputed values |
X |
vector of true values |
This function returns the value of similarity of two vectors corresponding to univariate signals.
A higher similarity (Similarity \in [0, 1]) highlights a more accurate method for completing missing values in univariate datasets.
Both vectors Y and X must be of equal length, on the contrary an error will be displayed.
In both input vectors, eventual NA will be excluded with a warning displayed.
data(dataDTWBI)
X <- dataDTWBI[, 1] ; Y <- dataDTWBI[, 2]
compute.sim(Y,X)
# By definition, if true values is a constant vector
# and one or more imputed values are equal to the true values,
# similarity = 1.
X <- rep(2, 10)
Y <- X
compute.sim(Y,X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.